@@ -1,7 +1,5 @@
 package IRC::Mode::Single;
-{
-  $IRC::Mode::Single::VERSION = '0.088001';
-}
+$IRC::Mode::Single::VERSION = '0.088002';
 use strictures 1;
 use Carp;
 
@@ -34,15 +32,11 @@ sub param { $_[0]->[PARAM] }
 
 sub as_string {
   my ($self) = @_;
-  my $str = $self->[FLAG] . $self->[MODE];
-  $str .= " ".$self->[PARAM] if defined $self->[PARAM];
-  $str
+  $self->[FLAG] . $self->[MODE]
+    . (defined $self->[PARAM] ? ' '.$self->[PARAM] : '')
 }
 
-sub export {
-  my ($self) = @_;
-  [ @$self ]
-}
+sub export { [ @{$_[0]} ] }
 
 1;
 
